@@ -156,9 +156,10 @@ class FlaviusHeader(FlaviusBase):
     """
     def __init__(self):
         super(FlaviusHeader, self).__init__(search_url=conf.FLAVIUS_API_HEADER_FETCH,
-                                            create_url='', update_url='', delete_url='')
+                                            create_url=conf.FLAVIUS_API_HEADER_CREATE,
+                                            update_url='', delete_url='')
 
-    def search(self, query=None):
+    def search(self, query=dict(slip_type=0)):
         self.search_url += parse.urlencode(query=query, doseq=True)
 
         return super(FlaviusHeader, self).search(query=query)
