@@ -54,6 +54,10 @@ class Settings:
     def FLAVIUS_API_DTO_FETCH(self):
         return getattr(settings, "FLAVIUS_API_DTO_FETCH", 'api/dto_fetch.php')
 
+    @property
+    def FLAVIUS_API_HEADER_CREATE(self):
+        return getattr(settings, "FLAVIUS_API_HEADER_CREATE", 'api/header_create.php')
+
     @property
     def FLAVIUS_API_HEADER_FETCH(self):
         return getattr(settings, "FLAVIUS_API_HEADER_FETCH", 'api/header_fetch.php')
